/** 
 * @file
 *          main.c
 *
 * @brief   
 *          Application main file which keeps entery point to initialize peripherals and then runs while-loop.
 *
 */

#include <stdbool.h>
#include <stdint.h>
#include <stdio.h>
#include "nrf.h"
#include "nrf_gpio.h"
#include "nrf_gpiote.h"
#include "typedef.h"
#include "nrf_delay.h"


void TIMER2_IRQHandler(void)
{	
    if (NRF_TIMER2->EVENTS_COMPARE[2] == 1)
    {
        NRF_TIMER2->EVENTS_COMPARE[2] = 0;
    }
}


void InitClock(void)
{
    /* Start 16 MHz crystal oscillator */
    NRF_CLOCK->EVENTS_HFCLKSTARTED = 0;
    NRF_CLOCK->TASKS_HFCLKSTART = 1;
  
    // Wait for the external oscillator to start up.
    while (NRF_CLOCK->EVENTS_HFCLKSTARTED == 0) 
    {
        // Do nothing.
    }
}

/** 
 * @brief It initializes the timer-2 for system-tick.
 */
void InitTickTimer(void)
{
    NRF_TIMER2->MODE = TIMER_MODE_MODE_Timer;  // Set the timer in Timer Mode
    NRF_TIMER2->PRESCALER = 9;                 // Prescaler 9 produces 31250 Hz timer frequency => 1 tick = 32 us
    NRF_TIMER2->BITMODE = TIMER_BITMODE_BITMODE_16Bit;//TIMER_BITMODE_BITMODE_32Bit; //TIMER_BITMODE_BITMODE_16Bit;  // 16-bit mode

    NRF_TIMER2->TASKS_CLEAR = 1;               // clear the task first to be usable for later
    NRF_TIMER2->CC[2] = 0xffff; // compare on overflow

    NRF_TIMER2->TASKS_START = 1;               // Start clocks
    // Enable interrupt:
    NVIC_EnableIRQ(TIMER2_IRQn);
    
    NRF_TIMER2->INTENSET = TIMER_INTENSET_COMPARE2_Msk;
}


/**
 * @brief Function for main application entry.
 */
int main(void)
{
    InitClock();
    InitTickTimer();

    while(1) {     
//        __WFI();
        __WFE();
        __SEV();
        __WFE();
    }
    
   
}

